@@ -1,7 +1,7 @@
 
 import functools
 
-def myadd(numbers):
+def myadd(*numbers):
 	"""This function take arbitrary number of arguments and return the sum of all"""
 	list_1 = list(numbers)
 	sum = functools.reduce(lambda a, b : a + b, list_1)
@@ -25,6 +25,6 @@ def mydiv(a, b):
 	return a / b
 
 
-def power(a, b):
+def mypower(a, b):
     """This function is used for taking power"""
     return a ** b
